[−][src]Macro all_asserts::assert_gt
Asserts that the left hand side expression is greater than the right hand side expression
Examples
let a = 100; let b = 100; assert_gt!(a, b); // This would panic
Asserts that the left hand side expression is greater than the right hand side expression
let a = 100; let b = 100; assert_gt!(a, b); // This would panic