[−][src]Macro all_asserts::assert_le
Asserts that the left hand side expression is lesser than or equal to the right hand side expression
Examples
let a = 200; let b = 100; assert_gt!(a, b); // This would panic
Asserts that the left hand side expression is lesser than or equal to the right hand side expression
let a = 200; let b = 100; assert_gt!(a, b); // This would panic