[][src]Macro all_asserts::assert_nrange

macro_rules! assert_nrange {
    ($left:expr, $right:expr) => { ... };
    ($left:expr, $right:expr,) => { ... };
    ($left:expr, $right:expr, $($arg:tt)+) => { ... };
}

Asserts that the right hand side expression is not within the range on the left hand side

Examples

assert_nrange!((100..200), 1000);