[−][src]Macro all_asserts::assert_range
Asserts that the right hand side expression is within the range on the left hand side
Examples
assert_range!((100..200), 101);
Asserts that the right hand side expression is within the range on the left hand side
assert_range!((100..200), 101);